==> kubernetes-model-1.0.23-sources.jar: annotations/io/fabric8/openshift/api/model/NamedRoleBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class NamedRoleBuilder extends NamedRoleFluent<NamedRoleBuilder> implements VisitableBuilder<NamedRole,NamedRoleBuilder>{

     NamedRoleFluent<?> fluent;
public NamedRoleBuilder(){
    this(new NamedRole());
}
public NamedRoleBuilder( NamedRoleFluent<?> fluent ){
    this(fluent, new NamedRole());
}
public NamedRoleBuilder( NamedRoleFluent<?> fluent , NamedRole instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withRole(instance.getRole()); 
}
public NamedRoleBuilder( NamedRole instance ){
    this.fluent = this; this.withName(instance.getName()); this.withRole(instance.getRole()); 
}

public EditableNamedRole build(){
    EditableNamedRole buildable = new EditableNamedRole(fluent.getName(),fluent.getRole());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedRoleBuilder that = (NamedRoleBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.42-sources.jar: annotations/io/fabric8/openshift/api/model/NamedRoleBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class NamedRoleBuilder extends NamedRoleFluentImpl<NamedRoleBuilder> implements VisitableBuilder<NamedRole,NamedRoleBuilder>{

     NamedRoleFluent<?> fluent;
public NamedRoleBuilder(){
    this(new NamedRole());
}
public NamedRoleBuilder( NamedRoleFluent<?> fluent ){
    this(fluent, new NamedRole());
}
public NamedRoleBuilder( NamedRoleFluent<?> fluent , NamedRole instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withRole(instance.getRole()); 
}
public NamedRoleBuilder( NamedRole instance ){
    this.fluent = this; this.withName(instance.getName()); this.withRole(instance.getRole()); 
}

public EditableNamedRole build(){
    EditableNamedRole buildable = new EditableNamedRole(fluent.getName(),fluent.getRole());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedRoleBuilder that = (NamedRoleBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
